[PATCH 7/8] staging: ks7010: avoid CamelCase: reqIEs_size and respIEs_size

Janusz Lisiecki janusz.lisiecki at gmail.com
Sat Apr 29 20:58:47 UTC 2017


Replace CamelCase association_request_t and association_response_t
struct field names with underscores to comply with the standard kernel
coding style.

Signed-off-by: Janusz Lisiecki <janusz.lisiecki at gmail.com>
---
 drivers/staging/ks7010/ks_hostif.c | 10 +++++-----
 drivers/staging/ks7010/ks_hostif.h |  6 +++---
 2 files changed, 8 insertions(+), 8 deletions(-)

diff --git a/drivers/staging/ks7010/ks_hostif.c b/drivers/staging/ks7010/ks_hostif.c
index 856f714..05436bb 100644
--- a/drivers/staging/ks7010/ks_hostif.c
+++ b/drivers/staging/ks7010/ks_hostif.c
@@ -947,18 +947,18 @@ void hostif_associate_indication(struct ks_wlan_private *priv)
 	wrqu.data.length += sizeof(associnfo_leader0) - 1;
 	pbuf += sizeof(associnfo_leader0) - 1;
 
-	for (i = 0; i < assoc_req->reqIEs_size; i++)
+	for (i = 0; i < assoc_req->req_ies_size; i++)
 		pbuf += sprintf(pbuf, "%02x", *(pb + i));
-	wrqu.data.length += (assoc_req->reqIEs_size) * 2;
+	wrqu.data.length += (assoc_req->req_ies_size) * 2;
 
 	memcpy(pbuf, associnfo_leader1, sizeof(associnfo_leader1) - 1);
 	wrqu.data.length += sizeof(associnfo_leader1) - 1;
 	pbuf += sizeof(associnfo_leader1) - 1;
 
-	pb += assoc_req->reqIEs_size;
-	for (i = 0; i < assoc_resp->respIEs_size; i++)
+	pb += assoc_req->req_ies_size;
+	for (i = 0; i < assoc_resp->resp_ies_size; i++)
 		pbuf += sprintf(pbuf, "%02x", *(pb + i));
-	wrqu.data.length += (assoc_resp->respIEs_size) * 2;
+	wrqu.data.length += (assoc_resp->resp_ies_size) * 2;
 
 	pbuf += sprintf(pbuf, ")");
 	wrqu.data.length += 1;
diff --git a/drivers/staging/ks7010/ks_hostif.h b/drivers/staging/ks7010/ks_hostif.h
index 27274d4..0e3a956 100644
--- a/drivers/staging/ks7010/ks_hostif.h
+++ b/drivers/staging/ks7010/ks_hostif.h
@@ -482,7 +482,7 @@ struct association_request_t {
 	u16 capability;
 	u16 listen_interval;
 	u8 ap_address[6];
-	u16 reqIEs_size;
+	u16 req_ies_size;
 } __packed;
 
 struct association_response_t {
@@ -493,14 +493,14 @@ struct association_response_t {
 	u16 capability;
 	u16 status;
 	u16 association_id;
-	u16 respIEs_size;
+	u16 resp_ies_size;
 } __packed;
 
 struct hostif_associate_indication_t {
 	struct hostif_hdr header;
 	struct association_request_t assoc_req;
 	struct association_response_t assoc_resp;
 	/* followed by (reqIEs_size + respIEs_size) octets of data */
 	/* reqIEs data *//* respIEs data */
 } __packed;
 
@@ -493,14 +493,14 @@ struct association_response_t {
 	struct association_request_t assoc_req;
 	struct association_response_t assoc_resp;
-	/* followed by (reqIEs_size + respIEs_size) octets of data */
+	/* followed by (req_ies_size + resp_ies_size) octets of data */
 	/* reqIEs data *//* respIEs data */
 } __packed;
-- 
1.9.1



More information about the devel mailing list